searchData={"items":[{"type":"module","title":"WeightedRandom","doc":"Sometimes random is *too* random. Use this to add a bias toward a certain value (or values)\n  Also supports such values impacting their neighbours\n\n  Not intended to be cryptographically secure.\n  Also not nearly as performant as a simple Enum.random/1, so consider whether you actually need this.","ref":"WeightedRandom.html"},{"type":"function","title":"WeightedRandom.rand/3","doc":"Takes a list or range of values, and another list of weights.\n\nEvery value in the range automatically gets a weight of 1.\nWhen you pass in `%{target: 25, weight: 2}` this is actually ADDING 2 to the total number of 'votes' that 25 gets.\n\nAnd when you add a radius: Now the surrounding values also get a boost.\n\n\nAs an example: `%{target: 10, weight: 10, radius: 3}`\n- there are 3 extra votes for 8\n- there are 7 extra votes for 9\n- There are 10 extra votes for 10\n- there are 7 extra votes for 11\n- there are 3 extra votes for 12\n\n(Yes the numbers are rounded)\n\nAnd this is only using a linear curve. You could also pass in something like:\n\n`%{target: 10, weight: 10, radius: 3, curve: :ease_out}`\n\nWhich will change how much of a boost goes to the surrounding values caught in the radius.","ref":"WeightedRandom.html#rand/3"},{"type":"function","title":"Allowed Curve Types - WeightedRandom.rand/3","doc":"```elixir\n:linear (default)\n:ease\n:ease_in\n:ease_out\n:ease_in_out\n:ease_in_quad\n:ease_in_cubic\n:ease_in_quart\n:ease_in_quint\n:ease_in_sine\n:ease_in_expo\n:ease_in_circ\n:ease_in_back\n:ease_out_quad\n:ease_out_cubic\n:ease_out_quart\n:ease_out_quint\n:ease_out_sine\n:ease_out_expo\n:ease_out_circ\n:ease_out_back\n:ease_in_out_quad\n:ease_in_out_cubic\n:ease_in_out_quart\n:ease_in_out_quint\n:ease_in_out_sine\n:ease_in_out_expo\n:ease_in_out_circ\n:ease_in_out_back\n```","ref":"WeightedRandom.html#rand/3-allowed-curve-types"},{"type":"function","title":"Examples - WeightedRandom.rand/3","doc":"iex> # You won't need this. It's only necessary for consistent test results.\n    iex> :rand.seed(:exsss, {100, 101, 102})\n    iex>\n    iex>\n    iex> range = 1..10\n    iex> weights = [%{target: 2, weight: 10}]\n    iex> Stream.repeatedly(fn -> rand(range, weights) end) |> Enum.take(10)\n    [4, 3, 3, 4, 4, 3, 3, 9, 10, 3]\n    iex>\n    iex> # Notice that it was biasing toward the INDEX of 2, not the value of 2.\n    iex> # When the list only includes integers, we can actually target values instead.\n    iex> # Notice we are now passing in the `index: false` option.\n    iex> Stream.repeatedly(fn -> rand(range, weights, index: false) end) |> Enum.take(10)\n    [7, 2, 2, 7, 2, 2, 1, 7, 2, 8]\n    iex>\n    iex> # Let's play with radius!\n    iex> weights = [%{target: 25, weight: 20, radius: 5}]\n    iex> range = 1..50\n    iex> # Here, the radius of 5 means that extra weight is given to 20..24 and 26..30\n    iex> Stream.repeatedly(fn -> rand(range, weights, index: false) end) |> Enum.take(10)\n    [29, 35, 27, 23, 25, 23, 24, 17, 23, 27]\n    iex>\n    iex> # We are not limited to integers\n    iex> range = [true, false, nil, \"Apples\", :boat]\n    iex> weights = [%{target: 0, weight: 100}]\n    iex> Stream.repeatedly(fn -> rand(range, weights) end) |> Enum.take(3)\n    [true, true, true]\n    iex>\n    iex>","ref":"WeightedRandom.html#rand/3-examples"},{"type":"function","title":"Finally, there is no limit to how many weights you can use. - WeightedRandom.rand/3","doc":"iex> range = 1..10\n    iex> weight1 = %{target: 7, weight: 15, radius: 4, curve: :ease_in_sine}\n    iex> weight2 = %{target: 1, weight: 35}\n    iex> weights = [weight1, weight2]\n    iex> Stream.repeatedly(fn -> rand(range, weights, index: false) end) |> Enum.take(10)\n    [8, 1, 1, 5, 8, 6, 7, 7, 1, 10]","ref":"WeightedRandom.html#rand/3-finally-there-is-no-limit-to-how-many-weights-you-can-use"},{"type":"module","title":"WeightedRandom.CubicBezier","doc":"Copied from https://github.com/bjunc/cubic-bezier/tree/master\nUnfortunately the build seems to be broken so I could not use it directly.","ref":"WeightedRandom.CubicBezier.html"},{"type":"function","title":"WeightedRandom.CubicBezier.solve/3","doc":"Given `x` (a float between `0.0` and `1.0`), compute the `y`. \n\nEither an easing atom or control points tuple can be provided.  \nMost common easing equations are support, but if an unsupported atom \nis given, the control points for `:linear` are returned.\n\nSee: https://gist.github.com/terkel/4377409","ref":"WeightedRandom.CubicBezier.html#solve/3"},{"type":"function","title":"Options - WeightedRandom.CubicBezier.solve/3","doc":"- `duration` (integer) - can provide greater accuracy.  \nThe default duration is 400 (ms), which is a common animation / transition duration.","ref":"WeightedRandom.CubicBezier.html#solve/3-options"},{"type":"function","title":"Examples - WeightedRandom.CubicBezier.solve/3","doc":"```elixir\niex> WeightedRandom.CubicBezier.solve(0.50, :ease_out_quad)\n0.7713235628639843\n```\n\n```elixir\niex> WeightedRandom.CubicBezier.solve(0.5, {0.250,  0.460,  0.450,  0.940})\n0.7713235628639843\n```\n\n```elixir\niex(1)> Enum.map([0.0, 0.25, 0.5, 0.75, 1.0], fn x -> \n...(1)> {x, Float.round(WeightedRandom.CubicBezier.solve(x, :ease_out_quad), 3)}\n...(1)> end)\n[{0.0, 0.0}, {0.25, 0.453}, {0.5, 0.771}, {0.75, 0.936}, {1.0, 1.0}]\n```","ref":"WeightedRandom.CubicBezier.html#solve/3-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [0.2.0] - 2024-05-27","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- Transferred ownership of the repo between two of my accounts.\n- Updated Readme and docs\n\n## [0.2.0] - 2024-05-27\nThis is a complete rebuild, and several functions are now deprecated.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- WeightedRandom.rand/3\n- Support for weights having a gravitational effect on surrounding values withing a specific radius\n- Support for that effect working on a number of different bezier curves","ref":"changelog.html#added"},{"type":"extras","title":"Deprecated - Changelog","doc":"In the interest of being a good library maintainer, I do not believe in making breaking changes ever. So the deprecated functions will continue to exist, undocumented and unmaintained.\n\nI wrote this library when I was first learning Elixir... I had no idea two of these functions already exist in the core library. The others are simply replaced by `rand`\n#### within the WeightedRandom module\n- between\n- numList\n- weighted\n- complex","ref":"changelog.html#deprecated"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}